<?php
/*
Plugin Name: Dovi WPGallery
Plugin URI:  http://dovi42.hu/wp-gallery
Description: WP media gallery view
Version:     0.01
Author:      Dovi
Author URI:  http://dovi42.hu
License:     GNU General Public License (GPL)
License URI: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
Text Domain: dovi-wpgallery
Generator:   WP Generator - http://dovi42.hu - 2019-11-22 14:30:44
*/


if ( !defined( 'ABSPATH' ) ) exit;

class dovi_wpgallery_694_settings
{
    private $options;

    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    public function add_plugin_page()
    {
        // This page will be under "Settings"
        add_options_page(
            'Settings Admin', 
            __('Dovi WPGallery settings', 'dovi-wpgallery'), 
            'manage_options', 
            'dovi-wpgallery-setting-admin', 
            array( $this, 'create_admin_page' )
        );
    }

    public function create_admin_page()
    {
        $this->options = dovi_wpgallery_694_get_options ( 'dovi_wpgallery_options' );
        ?>
        <div class="wrap">
            <h1><?php echo __('Dovi WPGallery settings', 'dovi-wpgallery');?></h1>
            <?php
                $active_tab = isset( $_GET[ 'tab' ] ) ? $_GET[ 'tab' ] : 'readme';
            ?>
            <h2 class="nav-tab-wrapper">
                <a href="?page=dovi-wpgallery-setting-admin&tab=readme" class="nav-tab  <?php echo $active_tab == 'readme' ? 'nav-tab-active' : ''; ?>"><?php echo __('Using plugin', 'dovi-wpgallery');?></a>
                <a href="?page=dovi-wpgallery-setting-admin&tab=settings" class="nav-tab  <?php echo $active_tab == 'settings' ? 'nav-tab-active' : ''; ?>"><?php echo __('Plugin settings', 'dovi-wpgallery');?></a>
            </h2>

            <?php
                switch ($active_tab){ 

                    case 'settings':
                        ?>
                        <form method="post" action="options.php">
                        <?php
                            // This prints out all hidden setting fields
                            settings_fields( 'dovi_wpgallery_option_main' );
                            do_settings_sections( 'dovi-wpgallery-setting-admin' );
                            submit_button();
                        ?>
                        </form>
                        <?php
                        exit;

                    default: 
                        echo '<h3>' . __('Using title', 'dovi-wpgallery'). '</h3>';
                        include( dirname(__FILE__) . DIRECTORY_SEPARATOR . 'how_to_use.php' );
                        /*
                            or 
                            include( dirname(__FILE__) . DIRECTORY_SEPARATOR . 'how_to_use_'.get_bloginfo('language').'.php' );
                            // include ./how_to_use_en.php
                        */
                }
            ?>

        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {        
        register_setting(
            'dovi_wpgallery_option_main', // Option group
            'dovi_wpgallery_options', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        add_settings_section(
            'dovi_wpgallery_settings_main', // ID
            __('Dovi WPGallery Custom Settings', 'dovi-wpgallery'), // Title
            array( $this, 'print_section_info' ), // Callback
            'dovi-wpgallery-setting-admin' // Page
        );  

        add_settings_field(
            'load_clearbox', // ID
            __('Load clearbox title', 'dovi-wpgallery'), // Title
            array( $this, 'useclearbox_callback' ), // Callback
            'dovi-wpgallery-setting-admin', // Page
            'dovi_wpgallery_settings_main' // Section
        );

        add_settings_field(
            'load_css', // ID
            __('Load default style', 'dovi-wpgallery'), // Title
            array( $this, 'usecss_callback' ), // Callback
            'dovi-wpgallery-setting-admin', // Page
            'dovi_wpgallery_settings_main' // Section
        );

    }

    public function sanitize( $input )
    {
        $new_input = array();

        if ( isset( $input['load_clearbox'] ) ) {
            $new_input['load_clearbox'] = 1;
        } else {
            $new_input['load_clearbox'] = 0;
        }

        if ( isset( $input['load_css'] ) ) {
            $new_input['load_css'] = 1;
        } else {
            $new_input['load_css'] = 0;
        }

        return $new_input;
    }

    public function print_section_info()
    {
        print __('Settings description', 'dovi-wpgallery');
    }

    public function useclearbox_callback()
    {
        if ($this->options['load_clearbox'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<input type="checkbox" name="dovi_wpgallery_options[load_clearbox]" value="1" '.$checked.' />' .
            '<br /><small>'.__('Load clearbox description.', 'dovi-wpgallery').'</small>',
            isset( $this->options['load_clearbox'] ) ? esc_attr( $this->options['load_clearbox']) : ''
        );
    }
    public function usecss_callback()
    {
        if ($this->options['load_css'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<input type="checkbox" name="dovi_wpgallery_options[load_css]" value="1" '.$checked.' />' .
            '<br /><small>'.__('Load css description.', 'dovi-wpgallery').'</small>',
            isset( $this->options['load_css'] ) ? esc_attr( $this->options['load_css']) : ''
        );
    }

}
